ytree\.arbor\.frontends\.consistent\_trees\.io\.ConsistentTreesTreeFieldIO
==========================================================================

.. currentmodule:: ytree.arbor.frontends.consistent_trees.io

.. autoclass:: ConsistentTreesTreeFieldIO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ConsistentTreesTreeFieldIO.__init__
      ~ConsistentTreesTreeFieldIO.get_fields
   
   

   
   
   